@@ -5,10 +5,10 @@ import logging
 import getopt
 
 #sys.path.append("./") 
-from communication import initializeMCParams, getAPIRequest
-from agents import getAgentList, getAgentByAttrs
-from jobs import appendToJobAgentList, addJob, getJobRunID, startJob, deleteJob, jobsMonitor, addSimpleSyncJob, getJobRunStatus, getJobByID
-from jobs_from_csv import jobsFromCSV
+from .communication.communication import initializeMCParams, getAPIRequest
+from .agents.agents import getAgentList, getAgentByAttrs
+from .jobs.jobs import appendToJobAgentList, addJob, getJobRunID, startJob, deleteJob, jobsMonitor, addSimpleSyncJob, getJobRunStatus, getJobByID
+from .jobs_from_csv.jobs_from_csv import jobsFromCSV
  
 # default values
 csvFileName = "./jobs.csv"
@@ -79,3 +79,4 @@ def main():
     jobsFromCSV(csvFileName, myJobsMonitor, doSomethingWhenJobIsDone, jobCount, 10)
 
 
+main()
\ No newline at end of file
